==> jc-1.4.0.tar.gz: java/awt/Dialog__24AccessibleAWTDialog.h <==
// public class java.awt.Dialog$AccessibleAWTDialog

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class fddb6aa15781bc09 java_awt_Dialog__24AccessibleAWTDialog
// @dep_class 2e728272befbb849 java_awt_Window__24AccessibleAWTWindow
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Window__24AccessibleAWTWindow

#include "java/awt/Window__24AccessibleAWTWindow.h"

#ifndef _JC_java_awt_Dialog__24AccessibleAWTDialog_H_
#define _JC_java_awt_Dialog__24AccessibleAWTDialog_H_

// Forward structure declarations
struct _jc_java_awt_Dialog$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_refs	_jc_java_awt_Dialog__24AccessibleAWTDialog$sub_refs;
typedef struct _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_nonrefs	_jc_java_awt_Dialog__24AccessibleAWTDialog$sub_nonrefs;
typedef struct _jc_java_awt_Dialog__24AccessibleAWTDialog$refs	_jc_java_awt_Dialog__24AccessibleAWTDialog$refs;
typedef struct _jc_java_awt_Dialog__24AccessibleAWTDialog$nonrefs	_jc_java_awt_Dialog__24AccessibleAWTDialog$nonrefs;
typedef struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object	_jc_java_awt_Dialog__24AccessibleAWTDialog$object;

typedef const struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vmethods	_jc_java_awt_Dialog__24AccessibleAWTDialog$vmethods;
typedef const struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vtable	_jc_java_awt_Dialog__24AccessibleAWTDialog$vtable;
typedef const struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vtype	_jc_java_awt_Dialog__24AccessibleAWTDialog$vtype;

// Constructors
extern void _jc_java_awt_Dialog__24AccessibleAWTDialog$method$_init$905d0395627341fd(_jc_env *, struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object *, struct _jc_java_awt_Dialog$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Dialog__24AccessibleAWTDialog$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object *);
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_Dialog__24AccessibleAWTDialog$method$getAccessibleState$d62bcb9c957ba1ff(_jc_env *, struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Dialog__24AccessibleAWTDialog$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_java_awt_Dialog__24AccessibleAWTDialog$method_info$getAccessibleState$d62bcb9c957ba1ff;

// Virtual methods structure
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object *);
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleState$d62bcb9c957ba1ff)(_jc_env *, struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object *);
};

// Vtable
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_java_awt_Window__24AccessibleAWTWindow$vmethods	java_awt_Window__24AccessibleAWTWindow;
	_jc_java_awt_Dialog__24AccessibleAWTDialog$vmethods	java_awt_Dialog__24AccessibleAWTDialog;
};

// Vtype
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vtype {
	_jc_type			type;
	_jc_java_awt_Dialog__24AccessibleAWTDialog$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_refs {
	struct _jc_java_awt_Dialog$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$refs {
    _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_refs	java_awt_Dialog__24AccessibleAWTDialog;
    _jc_java_awt_Window__24AccessibleAWTWindow$sub_refs	java_awt_Window__24AccessibleAWTWindow;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Window__24AccessibleAWTWindow$sub_nonrefs	java_awt_Window__24AccessibleAWTWindow;
    _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_nonrefs	java_awt_Dialog__24AccessibleAWTDialog;
};

// Object instance structure
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object {
	_jc_java_awt_Dialog__24AccessibleAWTDialog$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Dialog__24AccessibleAWTDialog$vtype	*vtype;
	_jc_java_awt_Dialog__24AccessibleAWTDialog$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Dialog__24AccessibleAWTDialog$vtype _jc_java_awt_Dialog__24AccessibleAWTDialog$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Dialog__24AccessibleAWTDialog, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Dialog__24AccessibleAWTDialog$class_object;

#endif	/* _JC_java_awt_Dialog__24AccessibleAWTDialog_H_ */

==> jc-1.4.5.tar.gz: java/awt/Dialog__24AccessibleAWTDialog.h <==
// public class java.awt.Dialog$AccessibleAWTDialog

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class fddb6aa15781bc09 java_awt_Dialog__24AccessibleAWTDialog
// @dep_class 7c1da994418530e9 java_awt_Window__24AccessibleAWTWindow
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Window__24AccessibleAWTWindow

#include "java/awt/Window__24AccessibleAWTWindow.h"

#ifndef _JC_java_awt_Dialog__24AccessibleAWTDialog_H_
#define _JC_java_awt_Dialog__24AccessibleAWTDialog_H_

// Forward structure declarations
struct _jc_java_awt_Dialog$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_refs	_jc_java_awt_Dialog__24AccessibleAWTDialog$sub_refs;
typedef struct _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_nonrefs	_jc_java_awt_Dialog__24AccessibleAWTDialog$sub_nonrefs;
typedef struct _jc_java_awt_Dialog__24AccessibleAWTDialog$refs	_jc_java_awt_Dialog__24AccessibleAWTDialog$refs;
typedef struct _jc_java_awt_Dialog__24AccessibleAWTDialog$nonrefs	_jc_java_awt_Dialog__24AccessibleAWTDialog$nonrefs;
typedef struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object	_jc_java_awt_Dialog__24AccessibleAWTDialog$object;

typedef const struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vmethods	_jc_java_awt_Dialog__24AccessibleAWTDialog$vmethods;
typedef const struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vtable	_jc_java_awt_Dialog__24AccessibleAWTDialog$vtable;
typedef const struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vtype	_jc_java_awt_Dialog__24AccessibleAWTDialog$vtype;

// Constructors
extern void _jc_java_awt_Dialog__24AccessibleAWTDialog$method$_init$905d0395627341fd(_jc_env *, struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object *, struct _jc_java_awt_Dialog$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Dialog__24AccessibleAWTDialog$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_Dialog__24AccessibleAWTDialog$method$getAccessibleState$d62bcb9c957ba1ff(_jc_env *, struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Dialog__24AccessibleAWTDialog$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_java_awt_Dialog__24AccessibleAWTDialog$method_info$getAccessibleState$d62bcb9c957ba1ff;

// Virtual methods structure
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleState$d62bcb9c957ba1ff)(_jc_env *, struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_java_awt_Window__24AccessibleAWTWindow$vmethods	java_awt_Window__24AccessibleAWTWindow;
	_jc_java_awt_Dialog__24AccessibleAWTDialog$vmethods	java_awt_Dialog__24AccessibleAWTDialog;
};

// Vtype
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$vtype {
	_jc_type			type;
	_jc_java_awt_Dialog__24AccessibleAWTDialog$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_refs {
	struct _jc_java_awt_Dialog$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$refs {
    _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_refs	java_awt_Dialog__24AccessibleAWTDialog;
    _jc_java_awt_Window__24AccessibleAWTWindow$sub_refs	java_awt_Window__24AccessibleAWTWindow;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Window__24AccessibleAWTWindow$sub_nonrefs	java_awt_Window__24AccessibleAWTWindow;
    _jc_java_awt_Dialog__24AccessibleAWTDialog$sub_nonrefs	java_awt_Dialog__24AccessibleAWTDialog;
};

// Object instance structure
struct _jc_java_awt_Dialog__24AccessibleAWTDialog$object {
	_jc_java_awt_Dialog__24AccessibleAWTDialog$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Dialog__24AccessibleAWTDialog$vtype	*vtype;
	_jc_java_awt_Dialog__24AccessibleAWTDialog$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Dialog__24AccessibleAWTDialog$vtype _jc_java_awt_Dialog__24AccessibleAWTDialog$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Dialog__24AccessibleAWTDialog, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Dialog__24AccessibleAWTDialog$class_object;

#endif	/* _JC_java_awt_Dialog__24AccessibleAWTDialog_H_ */
